import logging

import click


@click.command()
@click.option('--debug', is_flag=True, help='Set log level to DEBUG.')
def main(debug) -> None:
    print(''' __       ___          __   __   __   ___  ___ 
|  \  /\   |   /\     /__` |__) |__) |__  |__  
|__/ /--\  |  /--\    .__/ |    |  \ |___ |___

Inference DS
    ''')
    if debug:
        logging.basicConfig(level=logging.DEBUG, format='%(asctime)s %(name)-42s %(levelname)-6s %(message)s')
    else:
        logging.basicConfig(level=logging.INFO, format='%(asctime)s %(name)-42s %(levelname)-6s %(message)s')
        logging.getLogger('aiohttp.access').setLevel(logging.WARNING)

    application = None

    try:
        from inds.core.application import Application
        application = Application()
        application.start()
    except KeyboardInterrupt:
        logging.info('Keyboard interrupt')
    except Exception as e:
        logging.error(f'An exception occurred: {e}')
        if debug:
            raise e

    if application is not None:
        logging.info('Stopping application...')
        application.stop()
    logging.info('Shutdown successful.')


if __name__ == '__main__':
    main()
