from enum import Enum


class ConfigFieldTypes(str, Enum):
    GROUP = 'group'
    GROUP_SELECTION = 'group_selection'
    GROUP_SWITCHABLE = 'group_switchable'
    BOOL_INPUT = 'bool_input'
    DOUBLE_INPUT = 'double_input'
    INTEGER_INPUT = 'integer_input'
    STRING_INPUT = 'string_input'
    JSON_TEXT_INPUT = 'json_text_input'
    SELECTION_DROPDOWN = 'selection_dropdown'

    def __json__(self):
        return self.value


TRIGGER_CONFIG_FIELD = \
    {
        'name': 'trigger',
        'type': ConfigFieldTypes.GROUP_SELECTION,
        'display_name': 'trigger',
        'description': 'Trigger for processing images of the node.',
        'default': 'default',
        'groups': [
            {
                'name': 'default_trigger',
                'type': ConfigFieldTypes.GROUP,
                'display_name': 'default',
                'description': 'Triggers for each image.',
                'fields': []
            },
            {
                'name': 'never_trigger',
                'type': ConfigFieldTypes.GROUP,
                'display_name': 'never',
                'description': 'Triggers never.',
                'fields': []
            },
            {
                'name': 'frame_skip_trigger',
                'type': ConfigFieldTypes.GROUP,
                'display_name': 'frame skip',
                'description': 'Triggers and skips the specified number of frames before the next frame is triggered.',
                'fields': [{
                    'name': 'skip_frames',
                    'type': ConfigFieldTypes.INTEGER_INPUT,
                    'display_name': 'skip frames',
                    'default': 0,
                    'description': 'Number of frames to skip'
                }]
            },
            {
                'name': 'difference_trigger',
                'type': ConfigFieldTypes.GROUP,
                'display_name': 'difference trigger',
                'description': 'Computed the difference between the triggered image and the next image. If the '
                               'difference exceeds the specified threshold, the frame is triggered.',
                'fields': [{
                    'name': 'threshold',
                    'type': ConfigFieldTypes.INTEGER_INPUT,
                    'display_name': 'threshold',
                    'default': 10,
                    'description': 'Difference threshold'
                }]
            }
        ],
    }
