from abc import ABC, abstractmethod
from typing import Dict, Optional, List

from inds.core.consumer import Consumer
from inds.core.plugin import Plugin
from inds.core.producer import Producer, Property


class SimplePlugin(Plugin, ABC):
    def __init__(self, name: str, properties: Optional[List[Property]] = None) -> None:
        super(SimplePlugin, self).__init__(name)

        self.producer: Producer = Producer(name, properties)
        self.add_producer(self.producer)

        self.consumer: Consumer = Consumer(name)
        self.add_consumer(self.consumer)

    @abstractmethod
    def process_item(self, item: Dict) -> Dict:
        """Process a single item and return it"""

    def run(self):
        """Run the processing loop"""

        while self.running:
            # get the next item from the consumer channel
            item = self.consumer.receive()

            if item is not None:
                # process the item
                item = self.process_item(item)

                if item is not None:
                    # send the processed item to all registered consumers
                    self.producer.send(item)
